searchNodes=[{"doc":"The LiveSelect field is rendered by calling the live_select/3 function and passing it a form and the name of the field. LiveSelect creates a text input field in which the user can type text, and a hidden input field that will contain the value of the selected option. As the text changes, LiveSelect will render a dropdown below the text input containing the matching options, which the user can then select. Selection can happen either using the keyboard, by navigating the options with the arrow keys and then pressing enter, or by clicking an option with the mouse. Whenever an option is selected, LiveSelect will trigger a standard phx-change event in the form. See the &quot;Examples&quot; section below for details on how to handle the event. After an option has been selected, the selection can be undone by clicking on text field. Reacting to user's input Whenever the user types something in the text input, LiveSelect sends a LiveSelect.ChangeMsg.t/0 message to your LiveView. The message has a text property containing the current text entered by the user, and a field property with the name of the LiveSelect field. The LiveView's job is to handle_info/2 the message and then call update_options/2 to update the dropdown's content with the new set of selectable options. See the &quot;Examples&quot; section below for details. Examples Here's an example that describes all the moving parts in detail. The user can search for cities. The LiveSelect main form input is called city_search . When a city is selected, the coordinates of that city will be the value of the form input. The name of the selected city is available in the text input field named city_search_text_input . Template: &lt; . form for = { :my_form } :let = { f } phx - change = &quot;change&quot; &gt; &lt; % = live_select f , :city_search % &gt; &lt; / . form &gt; LiveView: import LiveSelect @impl true def handle_info ( % LiveSelect.ChangeMsg { } = change_msg , socket ) do cities = City . search ( change_msg . text ) # cities could be: # [ {&quot;city name 1&quot;, [lat_1, long_1]}, {&quot;city name 2&quot;, [lat_2, long_2]}, ... ] # # but it could also be (no coordinates in this case): # [ &quot;city name 1&quot;, &quot;city name 2&quot;, ... ] # # or: # [ [label: &quot;city name 1&quot;, value: [lat_1, long_1]], [label: &quot;city name 2&quot;, value: [lat_2, long_2]], ... ] # # or even: # [&quot;city name 1&quot;: [lat_1, long_1], &quot;city name 2&quot;: [lat_2, long_2]] update_options ( change_msg , cities ) { :noreply , socket } end @impl true def handle_event ( &quot;change&quot; , %{ &quot;my_form&quot; =&gt; %{ &quot;city_search_text_input&quot; =&gt; city_name , &quot;city_search&quot; =&gt; city_coords } } , socket ) do IO . puts ( &quot;You selected city \#{ city_name } located at: \#{ city_coords } &quot; ) { :noreply , socket } end Multiple LiveSelect inputs in the same LiveView If you have multiple LiveSelect inputs in the same LiveView, you can distinguish them based on the field. For example: Template: &lt; . form for = { :my_form } :let = { f } phx - change = &quot;change&quot; &gt; &lt; % = live_select f , :city_search % &gt; &lt; % = live_select f , :album_search % &gt; &lt; / . form &gt; LiveView: @impl true def handle_info ( % LiveSelect.ChangeMsg { } = change_msg , socket ) do options = case change_msg . field do :city_search -&gt; City . search ( change_msg . text ) :album_search -&gt; Album . search ( change_msg . text ) end update_options ( change_msg , options ) { :noreply , socket } end","ref":"LiveSelect.html","title":"LiveSelect","type":"module"},{"doc":"Renders a LiveSelect input in a form with a given field name. LiveSelect renders a hidden input with name field which contains the selected option. The visible text input field will have the name \#{field}_text_input . Opts: disabled - set this to a truthy value to disable the input field placeholder - placeholder text for the input field debounce - number of milliseconds to wait after the last keystroke before sending a LiveSelect.ChangeMsg.t/0 message. Defaults to 100ms update_min_len - the minimum length of text in the text input field that will trigger an update of the dropdown. It has to be a positive integer. Defaults to 3 style - one of :tailwind (the default), :daisyui or :none . See the Styling section for details active_option_class , container_class , container_extra_class , dropdown_class , dropdown_extra_class , option_class , option_extra_class , text_input_class , text_input_extra_class , text_input_selected_class - see the Styling section for details","ref":"LiveSelect.html#live_select/3","title":"LiveSelect.live_select/3","type":"function"},{"doc":"Updates a LiveSelect component with new options. change_msg must be the LiveSelect.ChangeMsg.t/0 originally sent by the LiveSelect, and options is the new list of options that will be used to fill the dropdown. Each option will be assigned a label, which will be shown in the dropdown, and a value, which will be the value of the LiveSelect input when the option is selected. options can be any enumerable of the following elements: atoms, strings or numbers : In this case, each element will be both label and value for the option tuples : {label, value} corresponding to label and value for the option maps : %{label: label, value: value} keywords : [label: label, value: value] This means you can use maps and keyword lists to pass the list of options, for example: %{ Red : 1 , Yellow : 2 , Green : 3 } Will result in 3 options with labels :Red , :Yellow , :Green and values 1, 2, and 3. Note that the option values, if they are not strings, will be JSON-encoded. Your LiveView will receive this JSON-encoded version in the phx-change and phx-submit events.","ref":"LiveSelect.html#update_options/2","title":"LiveSelect.update_options/2","type":"function"},{"doc":"LiveSelect.ChangeMsg","ref":"LiveSelect.ChangeMsg.html","title":"LiveSelect.ChangeMsg","type":"module"},{"doc":"Message sent by LiveSelect components in response to text entered by the user in the text input field","ref":"LiveSelect.ChangeMsg.html#t:t/0","title":"LiveSelect.ChangeMsg.t/0","type":"type"},{"doc":"Dynamic selection field for LiveView. LiveSelect is a LiveView component that implements a dynamic selection field with a dropdown. The content of the dropdown is filled dynamically by your LiveView.","ref":"readme.html","title":"Readme","type":"extras"},{"doc":"To install, add this to your dependencies: [ { :live_select , &quot;~&gt; 0.2.0&quot; } ]","ref":"readme.html#installation","title":"Readme - Installation","type":"extras"},{"doc":"LiveSelect relies on Javascript hooks to work. You need to add LiveSelect 's hooks to your live socket. In your app.js file: import live_select from &quot;live_select&quot; // if you don &#39; t have any other hooks : let liveSocket = new LiveSocket ( &quot;/live&quot; , Socket , { params : { _csrf_token : csrfToken } , hooks : live_select } ) // if you have other hooks : const hooks = { MyHook : { // ... } , ... live_select } let liveSocket = new LiveSocket ( &quot;/live&quot; , Socket , { params : { _csrf_token : csrfToken } , hooks } )","ref":"readme.html#javascript-hooks","title":"Readme - Javascript Hooks","type":"extras"},{"doc":"LiveSelect supports 3 styling modes: tailwind : uses standard tailwind utility classes (the default) daisyui : uses daisyUI classes. none : no styling at all. The choice of style is controlled by the style option in live_select/3 . tailwind and daisyui styles come with sensible defaults which can be selectively extended or completely overridden. If you're using tailwind or daisyui styles, you need to add one of the following lines to the content section in your tailwind.config.js : module . exports = { content : [ // ... &#39;../deps/live_select/lib/live_select/component.*ex&#39; &lt;- - for a standalone app &#39;../../../deps/live_select/lib/live_select/component.*ex&#39; &lt;- - for an umbrella app ] // .. } Notice the different paths for a standalone or umbrella app. Refer to the Styling section for further details.","ref":"readme.html#tailwind-configuration","title":"Readme - Tailwind configuration","type":"extras"},{"doc":"The repository includes a showcase app that you can use to experiment with the different options and parameters for LiveSelect . To start the showcase app, simply run: mix setup PORT = 4001 mix phx . server from within the cloned repository. The app will be available at http://localhost:4001 . The showcase app allows you to quickly experiment with options and styles, providing an easy way to fine tune your LiveSelect component. The app also shows the messages and events that your LiveView receives. For each event or message, the app shows the function head of the callback that your LiveView needs to implement in order to handle the event.","ref":"readme.html#showcase-app","title":"Readme - Showcase app","type":"extras"},{"doc":"Refer to the online documentation .","ref":"readme.html#usage","title":"Readme - Usage","type":"extras"},{"doc":"[X] Add package.json to enable import live_select from &quot;live_select&quot; [X] Make sure component classes are included by tailwind [X] Enable custom styling [X] Rename LiveSelect.render to live_select [X] Customizable placeholder [X] Enable configuration of styles in the showcase app [X] Add support for vanilla tailwind styles [ ] Enable multiple options mode ( example ) [ ] Enable using custom HTML to display options","ref":"readme.html#todo","title":"Readme - TODO","type":"extras"},{"doc":"LiveSelect supports 3 styling modes: tailwind : uses standard tailwind utility classes (the default) daisyui : uses daisyUI classes. none : no styling at all. The choice of style is controlled by the style option in live_select/3 . tailwind and daisyui styles come with sensible defaults which can be extended or overridden via options. This is what each default style looks like: daisyui: (the actual colors may differ depending on the selected daisyui theme ) tailwind: These defaults can be selectively overridden or extended using the appropriate options to live_select/3 . You can control the style of the following elements: The outer container of the live_select component The text input field The text input field when an option has been selected The dropdown containing the selectable options The single selectable option (s) The currently active option Here's a visual representation of the elements: For each of these elements there is an {element}_class and for some also an {element}_extra_class option, which can be used to override or extend the default CSS classes for the element, respectively. You can't use both options together: use {element}_class to completely override the default classes, or use {element}_extra_class to extend the default. The following table shows the default styles for each element and the options you can use to adjust its CSS classes. Element Default tailwind classes Default daisyUI classes Class override option Class extend option container relative h-full text-black dropdown dropdown-open container_class container_extra_class text input rounded-md h-full w-full disabled:bg-gray-100 disabled:placeholder:text-gray-400 disabled:text-gray-400 input input-bordered w-full text_input_class text_input_extra_class text input selected border-gray-600 text-gray-600 border-2 input-primary text-primary text_input_selected_class dropdown absolute rounded-xl shadow z-50 bg-gray-100 w-full dropdown-content menu menu-compact shadow rounded-box bg-base-200 p-1 w-full dropdown_class dropdown_extra_class option rounded-lg px-4 py-1 hover:bg-gray-400 option_class option_extra_class active option text-white bg-gray-600 active active_option_class For example, if you want the options to use black text, the active option to have a red background, and remove rounded borders from both the dropdown and the active option, call live_select/3 like this: live_select ( form , field , active_option_class : &quot;text-white bg-red-800&quot; , dropdown_extra_class : &quot;!rounded-xl&quot; , option_extra_class : &quot;!rounded-lg text-black&quot; , style : :tailwind ) Selectively removing classes from defaults You can remove classes included with the style's defaults by using the !class_name notation in an {element}_extra_class option. For example, if a default style is rounded-lg px-4 , using an extra class option of !rounded-lg text-black will result in the following final class being applied to the element: px-4 text-black","ref":"styling.html","title":"Styling","type":"extras"},{"doc":"","ref":"changelog.html","title":"Changelog","type":"extras"},{"doc":"when disabled option is used, also disable hidden input style disabled text input in tailwind mode fix problem with selection via mouseclick when an input field is underneath the dropdown hide dropdown when user clicks away from component or input loses focus show dropdown when input obtains focus again using default black text in tailwind mode","ref":"changelog.html#0-2-1-2022-10-25","title":"Changelog - 0.2.1 (2022-10-25)","type":"extras"},{"doc":"support for tailwind styles (now the default) more opinionated default styles ability to selectively remove classes from style defaults using the !class_name notation rename option search_term_min_length to update_min_len better error messages various improvements to the showcase app","ref":"changelog.html#0-2-0-2022-10-03","title":"Changelog - 0.2.0 (2022-10-03)","type":"extras"},{"doc":"raise if class and extra_class options are used in invalid combinations ( https://github.com/maxmarcon/live_select/issues/2 ) Bugfixes route server events to the right live select component using the component id ( https://github.com/maxmarcon/live_select/issues/1 )","ref":"changelog.html#0-1-4-2022-09-20","title":"Changelog - 0.1.4 (2022-09-20)","type":"extras"},{"doc":"rename LiveSelect.update/2 to LiveSelect.update_options/2 add debounce option add search delay option to showcase app JSON-encode option values before assigning them to the hidden input field add LiveSelect.ChangeMsg struct to be used as change message","ref":"changelog.html#0-1-3-2022-08-12","title":"Changelog - 0.1.3 (2022-08-12)","type":"extras"},{"doc":"Disable input field via options Placeholder text via options Improve docs and showcase app Remove setting component id via options Bugfixes Use atoms as field names, because strings are not accepted by Ecto forms","ref":"changelog.html#0-1-2-2022-08-10","title":"Changelog - 0.1.2 (2022-08-10)","type":"extras"},{"doc":"Remove all colors from default daisyui styles Improve styling of showcase app Improve docs Remove the msg_prefix option in favor of change_msg","ref":"changelog.html#0-1-1-2022-08-09","title":"Changelog - 0.1.1 (2022-08-09)","type":"extras"},{"doc":"First version 🎉","ref":"changelog.html#0-1-0-2022-08-09","title":"Changelog - 0.1.0 (2022-08-09)","type":"extras"}]